==> open-xchange-realtime-core_7.4.0.orig.tar.bz2: open-xchange-realtime-core-7.4.0/com.openexchange.realtime.hazelcast/src/com/openexchange/realtime/hazelcast/Utils.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.hazelcast;

import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.realtime.dispatch.DispatchExceptionCode;
import com.openexchange.realtime.packet.ID;
import com.openexchange.realtime.packet.Stanza;


/**
 * {@link Utils}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class Utils {
    public static boolean shouldResend(Map<ID, OXException> sendErrors, Stanza stanza) {
        if (sendErrors.isEmpty()) {
            return false;
        }
        OXException exception = sendErrors.get(stanza.getTo());
        if (exception == null) {
            return false;
        }
        Throwable cause = exception.getCause();
        if (cause == null) {
            return false;
        }
        if (cause instanceof OXException) {
            OXException oxexception = (OXException) cause;
            if ( DispatchExceptionCode.RESOURCE_OFFLINE.equals(oxexception)) {
                return true;
            }
        }
        return false;
    }
}

==> open-xchange-realtime-core_7.6.0.orig.tar.bz2: open-xchange-realtime-core-7.6.0/com.openexchange.realtime.hazelcast/src/com/openexchange/realtime/hazelcast/Utils.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2014 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.realtime.hazelcast;

import java.util.Map;
import com.openexchange.exception.OXException;
import com.openexchange.realtime.dispatch.DispatchExceptionCode;
import com.openexchange.realtime.packet.ID;
import com.openexchange.realtime.packet.Stanza;


/**
 * {@link Utils}
 *
 * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
 */
public class Utils {

    /**
     * Check if an {@link DispatchExceptionCode.RESOURCE_OFFLINE} occurred while trying to reach the exact recipient specified in the stanza
     * iow. stanza.getTo().isGeneral() == false. This is the case when e.g. addressing synthetic resources like
     * "synthetic.office://operations@1/28041.219886"
     * 
     * @param sendErrors The map of ID -> Exception that was the result when trying to send a {@link Stanza} 
     * @param stanza The {@link Stanza} you tried to send
     * @return true if the exact ID was offline, false otherwise
     */
    public static boolean shouldResend(Map<ID, OXException> sendErrors, Stanza stanza) {
        if (sendErrors.isEmpty()) {
            return false;
        }
        OXException exception = sendErrors.get(stanza.getTo());
        if (exception == null) {
            return false;
        }
        Throwable cause = exception.getCause();
        if (cause == null) {
            return false;
        }
        if (cause instanceof OXException) {
            OXException oxexception = (OXException) cause;
            if ( DispatchExceptionCode.RESOURCE_OFFLINE.equals(oxexception)) {
                return true;
            }
        }
        return false;
    }

}
